[![snapcraft](https://snapcraft.io/snapcraft/badge.svg)](https://snapcraft.io/snapcraft) [![Build Status][travis-image]][travis-url] [![Coverage Status][codecov-image]][codecov-url]
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black)


# Snapcraft

Package, distribute, and update any app for Linux and IoT.

Snaps are containerised software packages that are simple to create and 
install. They auto-update and are safe to run. And because they bundle their
dependencies, they work on all major Linux systems without modification.

[Build your first snap](https://docs.snapcraft.io/build-snaps/languages) or learn more about how [Snapcraft can help you](https://snapcraft.io).

## Get support

We’re here to help. Ask your questions at the [Snapcraft Forum](https://forum.snapcraft.io). Report bugs on [Launchpad](https://bugs.launchpad.net/snapcraft/+filebug).

Learn about the latest features by following Snapcraft on
[Twitter](https://twitter.com/snapcraftio) or
[Facebook](https://www.facebook.com/snapcraftio).

## Contribute to Snapcraft

We love contributors. Read the [hacking guide](HACKING.md) if you're interested in helping out.


[travis-image]: https://travis-ci.org/snapcore/snapcraft.svg?branch=master
[travis-url]: https://travis-ci.org/snapcore/snapcraft

[codecov-image]: https://codecov.io/github/snapcore/snapcraft/coverage.svg?branch=master
[codecov-url]: https://codecov.io/github/snapcore/snapcraft?branch=master
